from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from ...UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class DamageEvolution:
    """The DamageEvolution object specifies material properties to define the evolution of
    damage.

    .. note:: 
        This object can be accessed by::

            import material
            mdb.models[name].materials[name].ductileDamageInitiation.damageEvolution
            mdb.models[name].materials[name].fldDamageInitiation.damageEvolution
            mdb.models[name].materials[name].flsdDamageInitiation.damageEvolution
            mdb.models[name].materials[name].hashinDamageInitiation.damageEvolution
            mdb.models[name].materials[name].johnsonCookDamageInitiation.damageEvolution
            mdb.models[name].materials[name].maxeDamageInitiation.damageEvolution
            mdb.models[name].materials[name].maxpeDamageInitiation.damageEvolution
            mdb.models[name].materials[name].maxpsDamageInitiation.damageEvolution
            mdb.models[name].materials[name].maxsDamageInitiation.damageEvolution
            mdb.models[name].materials[name].mkDamageInitiation.damageEvolution
            mdb.models[name].materials[name].msfldDamageInitiation.damageEvolution
            mdb.models[name].materials[name].quadeDamageInitiation.damageEvolution
            mdb.models[name].materials[name].quadsDamageInitiation.damageEvolution
            mdb.models[name].materials[name].shearDamageInitiation.damageEvolution
            import odbMaterial
            session.odbs[name].materials[name].ductileDamageInitiation.damageEvolution
            session.odbs[name].materials[name].fldDamageInitiation.damageEvolution
            session.odbs[name].materials[name].flsdDamageInitiation.damageEvolution
            session.odbs[name].materials[name].hashinDamageInitiation.damageEvolution
            session.odbs[name].materials[name].johnsonCookDamageInitiation.damageEvolution
            session.odbs[name].materials[name].maxeDamageInitiation.damageEvolution
            session.odbs[name].materials[name].maxpeDamageInitiation.damageEvolution
            session.odbs[name].materials[name].maxpsDamageInitiation.damageEvolution
            session.odbs[name].materials[name].maxsDamageInitiation.damageEvolution
            session.odbs[name].materials[name].mkDamageInitiation.damageEvolution
            session.odbs[name].materials[name].msfldDamageInitiation.damageEvolution
            session.odbs[name].materials[name].quadeDamageInitiation.damageEvolution
            session.odbs[name].materials[name].quadsDamageInitiation.damageEvolution
            session.odbs[name].materials[name].shearDamageInitiation.damageEvolution

        The table data for this object are:

        - If **type** = DISPLACEMENT, and **softening** = LINEAR, and **mixedModeBehavior** = MODE_INDEPENDENT, the table data specify the following:
        
            - Equivalent total or Plastic displacement at failure, measured from the time of damage initiation.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = ENERGY, and **softening** = LINEAR, and **mixedModeBehavior** = MODE_INDEPENDENT, the table data specify the following:
        
            - Fracture energy.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = DISPLACEMENT, and **softening** = LINEAR, and **mixedModeBehavior** = TABULAR, the table data specify the following:
        
            - Total displacement at failure, measured from the time of damage initiation.
            - Appropriate mode mix ratio.
            - Appropriate mode mix ratio (if relevant, for three-dimensional problems with anisotropic shear behavior).
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = ENERGY, and **softening** = LINEAR, and **mixedModeBehavior** = TABULAR, the table data specify the following:
        
            - Fracture energy.
            - Appropriate mode mix ratio.
            - Appropriate mode mix ratio (if relevant, for three-dimensional problems with anisotropic shear behavior).
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = DISPLACEMENT, and **softening** = EXPONENTIAL, and **mixedModeBehavior** = MODE_INDEPENDENT, the table data specify the following:
        
            - Equivalent total or Plastic displacement at failure, measured from the time of damage initiation.
            - Exponential law parameter.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = ENERGY, and **softening** = EXPONENTIAL, and **mixedModeBehavior** = MODE_INDEPENDENT, the table data specify the following:
        
            - Fracture energy.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = DISPLACEMENT, and **softening** = EXPONENTIAL, and **mixedModeBehavior** = TABULAR, the table data specify the following:
        
            - Total displacement at failure, measured from the time of damage initiation.
            - Exponential law parameter.
            - Appropriate mode mix ratio.
            - Appropriate mode mix ratio (if relevant, for three-dimensional problems with anisotropic shear behavior).
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = ENERGY, and **softening** = EXPONENTIAL, and **mixedModeBehavior** = TABULAR, the table data specify the following:
        
            - Fracture energy.
            - Appropriate mode mix ratio.
            - Appropriate mode mix ratio (if relevant, for three-dimensional problems with anisotropic shear behavior).
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = DISPLACEMENT, and **softening** = TABULAR, and **mixedModeBehavior** = MODE_INDEPENDENT, the table data specify the following:
        
            - Damage variable.
            - Equivalent total or Plastic displacement, measured from the time of damage initiation.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = DISPLACEMENT, and **softening** = TABULAR, and **mixedModeBehavior** = TABULAR, the table data specify the following:
        
            - Damage variable.
            - Equivalent total or Plastic displacement, measured from the time of damage initiation.
            - Appropriate mode mix ratio.
            - Appropriate mode mix ratio (if relevant, for three-dimensional problems with anisotropic shear behavior).
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = ENERGY, and **softening** = LINEAR or EXPONENTIAL, and **mixedModeBehavior** = POWER_LAW or BK, the table data specify the following:
        
            - Normal mode fracture energy.
            - Shear mode fracture energy for failure in the first shear direction.
            - Shear mode fracture energy for failure in the second shear direction.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = ENERGY, **softening** = LINEAR and constructor for :py:class:`~abaqus.Material.ProgressiveDamageFailure.DamageInitiation.DamageInitiation` = HashinDamageInitiation, the table data specify the following:
        
            - Fiber tensile fracture energy.
            - Fiber compressive fracture energy.
            - Matrix tensile fracture energy.
            - Matrix compressive fracture energy.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.

        The corresponding analysis keywords are:

        - DAMAGE EVOLUTION
    """

    @abaqus_method_doc
    def __init__(
        self,
        type: SymbolicConstant,
        table: tuple,
        degradation: SymbolicConstant = MAXIMUM,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        mixedModeBehavior: SymbolicConstant = MODE_INDEPENDENT,
        modeMixRatio: SymbolicConstant = ENERGY,
        power: float = None,
        softening: SymbolicConstant = LINEAR,
    ):
        """This method creates a DamageEvolution object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].materials[name].ductileDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].fldDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].flsdDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].hashinDamageInitiation.DamageEvolution.DamageEvolutione].materials[name].johnsonCookDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].maxeDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].maxpeDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].maxpsDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].maxsDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].mkDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].msfldDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].quadeDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].quadsDamageInitiation.DamageEvolution
                mdb.models[name].materials[name].shearDamageInitiation.DamageEvolution
                session.odbs[name].materials[name].ductileDamageInitiation.DamageEvolution
                session.odbs[name].materials[name].fldDamageInitiation.DamageEvolution
                session.odbs[name].materials[name].flsdDamageInitiation.DamageEvolution.DamageEvolutioname].materials[name].hashinDamageInitiation.DamageEvolution.DamageEvolutioname].materials[name].johnsonCookDamageInitiation.DamageEvolution.DamageEvolutioname].materials[name].maxeDamageInitiation.DamageEvolution
                session.odbs[name].materials[name].maxpeDamageInitiation.DamageEvolution
                session.odbs[name].materials[name].maxpsDamageInitiation.DamageEvolution
                session.odbs[name].materials[name].maxsDamageInitiation.DamageEvolution
                session.odbs[name].materials[name].mkDamageInitiation.DamageEvolution
                session.odbs[name].materials[name].msfldDamageInitiation.DamageEvolution.DamageEvolutioname].materials[name].quadeDamageInitiation.DamageEvolution.DamageEvolutioname].materials[name].quadsDamageInitiation.DamageEvolution
                session.odbs[name].materials[name].shearDamageInitiation.DamageEvolution
            
        Parameters
        ----------
        type
            A SymbolicConstant specifying the type of damage evolution. Possible values are 
            DISPLACEMENT and ENERGY. 
        table
            A sequence of sequences of Floats specifying the items described below. 
        degradation
            A SymbolicConstant specifying the degradation. Possible values are MAXIMUM and 
            MULTIPLICATIVE. The default value is MAXIMUM. 
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF. 
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0. 
        mixedModeBehavior
            A SymbolicConstant specifying the mixed mode behavior. Possible values are 
            MODE_INDEPENDENT, TABULAR, POWER_LAW, and BK. The default value is MODE_INDEPENDENT. 
        modeMixRatio
            A SymbolicConstant specifying the mode mix ratio. Possible values are ENERGY and 
            TRACTION. The default value is ENERGY. 
        power
            None or a Float specifying the exponent in the power law or the Benzeggagh-Kenane 
            criterion that defines the variation of fracture energy with mode mix for cohesive 
            elements. The default value is None. 
        softening
            A SymbolicConstant specifying the softening. Possible values are LINEAR, EXPONENTIAL, 
            and TABULAR. The default value is LINEAR. 

        Returns
        -------
        DamageEvolution
            A :py:class:`~abaqus.Material.ProgressiveDamageFailure.DamageEvolution.DamageEvolution` object. 

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the DamageEvolution object.

        Raises
        ------
        RangeError
        """
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .Fastener import Fastener
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class AssembledFastener(Fastener):
    """The AssembledFastener object defines an assembled fastener.
    The AssembledFastener object is derived from the Fastener object.

    .. note:: 
        This object can be accessed by::

            import part
            mdb.models[name].parts[name].engineeringFeatures.fasteners[name]
            import assembly
            mdb.models[name].rootAssembly.engineeringFeatures.fasteners[name]
    """

    #: A Boolean specifying whether the fastener is suppressed or not. The default value is
    #: OFF.
    suppressed: Boolean = OFF

    #: A String specifying the repository key.
    name: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region of attachment points to which assembled fasteners
    #: are applied.
    region: Region

    #: A String specifying the name of the template model.
    templateModel: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the template model control point set. The set must contain a
    #: single node or vertex.
    controlSet: Region

    #: A sequence of Strings specifying the names of the template model surfaces that are
    #: referenced by tie or coupling constraints.
    templateSurfaces: tuple

    #: A sequence of Strings specifying the names of the master model surfaces that will be
    #: substituted for the template model constraint surfaces.
    assignedSurfaces: tuple

    #: A String specifying the name of the property prefix string. This string will be
    #: prepended to every property name as it is copied to the master model from the template
    #: model.
    propertyPrefix: str

    #: A SymbolicConstant specifying the method used to orient the virtual instances of the
    #: template model at each attachment point. Possible values are NORMALS and CSYS. The
    #: default value is NORMALS.
    orientMethod: SymbolicConstant = NORMALS

    #: None or a DatumCsys object specifying the local coordinate system. If **localCsys** = None,
    #: the global coordinate system is used. When this member is queried, it returns an Int.
    #: The default value is None.This argument applies only when **orientMethod** = CSYS.
    localCsys: int = None

    #: A String specifying the name of the property generation script. The default value is an
    #: empty string.
    scriptName: str = ""

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        region: Region,
        templateModel: str,
        controlSet: Region,
        templateSurfaces: tuple,
        assignedSurfaces: tuple,
        propertyPrefix: str,
        orientMethod: SymbolicConstant = NORMALS,
        localCsys: int = None,
        scriptName: str = "",
    ):
        """This method creates an AssembledFastener object. Although the constructor is available
        both for parts and for the assembly, AssembledFastener objects are currently supported
        only under the assembly.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].parts[name].engineeringFeatures.AssembledFastener
                mdb.models[name].rootAssembly.engineeringFeatures.AssembledFastener

        Parameters
        ----------
        name
            A String specifying the repository key.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region of attachment points to which assembled fasteners
            are applied.
        templateModel
            A String specifying the name of the template model.
        controlSet
            A :py:class:`~abaqus.Region.Region.Region` object specifying the template model control point set. The set must contain a
            single node or vertex.
        templateSurfaces
            A sequence of Strings specifying the names of the template model surfaces that are
            referenced by tie or coupling constraints.
        assignedSurfaces
            A sequence of Strings specifying the names of the master model surfaces that will be
            substituted for the template model constraint surfaces.
        propertyPrefix
            A String specifying the name of the property prefix string. This string will be
            prepended to every property name as it is copied to the master model from the template
            model.
        orientMethod
            A SymbolicConstant specifying the method used to orient the virtual instances of the
            template model at each attachment point. Possible values are NORMALS and CSYS. The
            default value is NORMALS.
        localCsys
            None or a DatumCsys object specifying the local coordinate system. If **localCsys** = None,
            the global coordinate system is used. When this member is queried, it returns an Int.
            The default value is None.This argument applies only when **orientMethod** = CSYS.
        scriptName
            A String specifying the name of the property generation script. The default value is an
            empty string.

        Returns
        -------
        AssembledFastener
            An :py:class:`~abaqus.EngineeringFeature.AssembledFastener.AssembledFastener` object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        orientMethod: SymbolicConstant = NORMALS,
        localCsys: int = None,
        scriptName: str = "",
    ):
        """This method modifies the AssembledFastener object.

        Parameters
        ----------
        orientMethod
            A SymbolicConstant specifying the method used to orient the virtual instances of the
            template model at each attachment point. Possible values are NORMALS and CSYS. The
            default value is NORMALS.
        localCsys
            None or a DatumCsys object specifying the local coordinate system. If **localCsys** = None,
            the global coordinate system is used. When this member is queried, it returns an Int.
            The default value is None.This argument applies only when **orientMethod** = CSYS.
        scriptName
            A String specifying the name of the property generation script. The default value is an
            empty string.
        """
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .MeshElementArray import MeshElementArray


@abaqus_class_doc
class MeshEdge:
    """The MeshEdge object refers to an element edge. It has no constructor or members. A
    MeshEdge object can be accessed via a MeshEdgeArray or a repository on a part or part
    instance.

    .. note:: 
        This object can be accessed by::

            import part
            mdb.models[name].parts[name].elemEdges[i]
            mdb.models[name].parts[name].elementEdges[i]
            import assembly
            mdb.models[name].rootAssembly.allInstances[name].elemEdges[i]
            mdb.models[name].rootAssembly.allInstances[name].elementEdges[i]
            mdb.models[name].rootAssembly.instances[name].elemEdges[i]
            mdb.models[name].rootAssembly.instances[name].elementEdges[i]
    """

    @abaqus_method_doc
    def getElements(self):
        """This method returns a tuple of elements that share the element edge.

        Returns
        -------
        typing.Tuple[MeshElement, ...]
            A tuple of :py:class:`~abaqus.Mesh.MeshElement.MeshElement` objects.
        """
        ...

    @abaqus_method_doc
    def getElementsViaTopology(self, domain: MeshElementArray = MeshElementArray([])):
        """This method returns an array of MeshElement objects that are obtained by recursively
        finding adjacent elements via topology.

        Parameters
        ----------
        domain
            A :py:class:`~abaqus.Mesh.MeshElementArray.MeshElementArray` object specifying the domain to include in the search. By default,
            all elements in the mesh are included.

        Returns
        -------
        MeshElementArray
            A :py:class:`~abaqus.Mesh.MeshElementArray.MeshElementArray` object, which is a sequence of MeshElement objects.
        """
        ...

    @abaqus_method_doc
    def getNodesViaTopology(self, domain: MeshElementArray = MeshElementArray([])):
        """This method returns an array of MeshNode objects that lie along element edges
        topologically in line with the element edge.

        Parameters
        ----------
        domain
            A :py:class:`~abaqus.Mesh.MeshElementArray.MeshElementArray` object specifying the domain to include in the search. By default,
            all elements in the mesh are included.

        Returns
        -------
        MeshNodeArray
            A :py:class:`~abaqus.Mesh.MeshNodeArray.MeshNodeArray` object, which is a sequence of MeshNode objects.
        """
        ...

    @abaqus_method_doc
    def getElemFaces(self):
        """This method returns a tuple of unique MeshFace objects that share the element edge.

        Returns
        -------
        typing.Tuple[MeshFace, ...]
            A tuple of :py:class:`~abaqus.Mesh.MeshFace.MeshFace` objects.
        """
        ...

    @abaqus_method_doc
    def getNodes(self):
        """This method returns a tuple of nodes on the element edge.

        Returns
        -------
        typing.Tuple[MeshNode, ...]
            A tuple of :py:class:`~abaqus.Mesh.MeshNode.MeshNode` objects.
        """
        ...



from abqpy.decorators import abaqus_class_doc
from .LoadState import LoadState
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class InwardVolAccelState(LoadState):
    """The InwardVolAccelState object stores the propagating data of an inward volume
    acceleration acoustic load in a step. One instance of this object is created internally
    by the InwardVolAccel object for each step. The instance is also deleted internally by
    the InwardVolAccel object.
    The InwardVolAccelState object has no constructor or methods.
    The InwardVolAccelState object is derived from the LoadState object.

    .. note:: 
        This object can be accessed by::

            import load
            mdb.models[name].steps[name].loadStates[name]

        The corresponding analysis keywords are:

        - CLOAD
    """

    #: A Float specifying the load magnitude.
    magnitude: float = None

    #: A SymbolicConstant specifying the propagation state of the load magnitude. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    magnitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the **amplitude** member. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    amplitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the LoadState object. Possible
    #: values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant = None

    #: A String specifying the name of the amplitude reference. The String is empty if the load
    #: has no amplitude reference.
    amplitude: str = ""



from typing import Optional
from typing_extensions import Literal
from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .Section import Section
from ..Connector.ConnectorBehaviorOptionArray import ConnectorBehaviorOptionArray
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class ConnectorSection(Section):
    """A :py:class:`~abaqus.Connector.ConnectorSection.ConnectorSection` object describes the connection type and the behavior of a connector.
    The ConnectorSection object is derived from the Section object.

    .. note:: 
        This object can be accessed by::

            import section
            mdb.models[name].sections[name]
            import odbSection
            session.odbs[name].sections[name]

        The corresponding analysis keywords are:

        - CONNECTOR SECTION
        - CONNECTOR BEHAVIOR
        - CONNECTOR CONSTITUTIVE REFERENCE
    """

    #: A String specifying the repository key.
    name: str

    #: A SymbolicConstant specifying the assembled connection type. Possible values
    #: are: NONE, BEAM, BUSHING, CVJOINT, CYLINDRICAL, HINGE, PLANAR, RETRACTOR, SLIPRING, TRANSLATOR, UJOINT, WELD
    #: The default value is NONE.You cannot include the **assembledType** argument if
    #: **translationalType** or **rotationalType** are given a value other than NONE. At least one
    #: of the arguments **assembledType**, **translationalType**, or **rotationalType** must be given
    #: a value other than NONE.
    assembledType: Literal[
        NONE,
        BEAM,
        BUSHING,
        CVJOINT,
        CYLINDRICAL,
        HINGE,
        PLANAR,
        RETRACTOR,
        SLIPRING,
        TRANSLATOR,
        UJOINT,
        WELD,
    ] = NONE

    #: A SymbolicConstant specifying the basic rotational connection type. Possible values
    #: are: NONE, ALIGN, CARDAN, CONSTANT_VELOCITY, EULER, FLEXION_TORSION, FLOW_CONVERTER, PROJECTION_FLEXION_TORSION,
    # REVOLUTE, ROTATION, ROTATION_ACCELEROMETER, UNIVERSAL. The
    #: default value is NONE.You cannot include the **rotationalType** argument if
    #: **assembledType** is given a value other than NONE. At least one of the arguments
    #: **assembledType**, **translationalType**, or **rotationalType** must be given an value other
    #: than NONE.
    rotationalType: Literal[
        NONE,
        ALIGN,
        CARDAN,
        CONSTANT_VELOCITY,
        EULER,
        FLEXION_TORSION,
        FLOW_CONVERTER,
        PROJECTION_FLEXION_TORSION,
        REVOLUTE,
        ROTATION,
        ROTATION_ACCELEROMETER,
        UNIVERSAL,
    ] = NONE

    #: A SymbolicConstant specifying the basic translational connection type. Possible values
    #: are: NONE, ACCELEROMETER, AXIAL, CARTESIAN, JOIN, LINK, PROJECTION_CARTESIAN, RADIAL_THRUST, SLIDE_PLANE, SLOT
    #: Thedefault value is NONE. You cannot include the **translationalType** argument if
    #: **assembledType** is given a value other than NONE. At least one of the arguments
    #: **assembledType**, **translationalType**, or **rotationalType** must be given an value other
    #: than NONE.
    translationalType: Literal[
        NONE,
        ACCELEROMETER,
        AXIAL,
        CARTESIAN,
        JOIN,
        LINK,
        PROJECTION_CARTESIAN,
        RADIAL_THRUST,
        SLIDE_PLANE,
        SLOT,
    ] = NONE

    #: A SymbolicConstant specifying the time integration scheme to use for analysis. This
    #: argument is applicable only to an Abaqus/Explicit analysis. Possible values are
    #: UNSPECIFIED, IMPLICIT, and EXPLICIT. The default value is UNSPECIFIED.
    integration: Literal[UNSPECIFIED, IMPLICIT, EXPLICIT] = UNSPECIFIED

    #: None or a Float specifying the reference length associated with constitutive response
    #: for the first component of relative motion. The default value is None.
    u1ReferenceLength: Optional[float] = None

    #: None or a Float specifying the reference length associated with constitutive response
    #: for the second component of relative motion. The default value is None.
    u2ReferenceLength: Optional[float] = None

    #: None or a Float specifying the reference length associated with constitutive response
    #: for the third component of relative motion. The default value is None.
    u3ReferenceLength: Optional[float] = None

    #: None or a Float specifying the reference angle in degrees associated with constitutive
    #: response for the fourth component of relative motion. The default value is None.
    ur1ReferenceAngle: Optional[float] = None

    #: None or a Float specifying the reference angle in degrees associated with constitutive
    #: response for the fifth component of relative motion. The default value is None.
    ur2ReferenceAngle: Optional[float] = None

    #: None or a Float specifying the reference angle in degrees associated with constitutive
    #: response for the sixth component of relative motion. The default value is None.
    ur3ReferenceAngle: Optional[float] = None

    #: None or a Float specifying the mass per unit reference length of belt material. This
    #: argument is applicable only when **assembledType** = SLIPRING, and must be specified in that
    #: case. The default value is None.
    massPerLength: Optional[float] = None

    #: None or a Float specifying the contact angle made by the belt wrapping around node b.
    #: This argument is applicable only to an Abaqus/Explicit analysis, and only when
    #: **assembledType** = SLIPRING. The default value is None.
    contactAngle: Optional[float] = None

    #: A Float specifying the scaling factor for material flow at node b. This argument is
    #: applicable only when **assembledType** = RETRACTOR or **rotationalType** = FLOW_CONVERTER. The
    #: default value is 1.0.
    materialFlowFactor: float = 1

    #: A Boolean specifying whether or not all tabular data associated with the
    #: **behaviorOptions** will be regularized. This argument is applicable only for an
    #: Abaqus/Explicit analysis. The default value is ON.
    regularize: Boolean = ON

    #: A Boolean specifying whether or not the default regularization tolerance will be used
    #: for all tabular data associated with the **behaviorOptions**. This argument is applicable
    #: only for an Abaqus/Explicit analysis and only if **regularize** = ON. The default value is
    #: ON.
    defaultTolerance: Boolean = ON

    #: A Float specifying the regularization increment to be used for all tabular data
    #: associated with the **behaviorOptions**. This argument is applicable only for an
    #: Abaqus/Explicit analysis and only if **regularize** = ON and **defaultTolerance** = OFF. The
    #: default value is 0.03.
    regularization: float = 0

    #: A SymbolicConstant specifying the extrapolation technique to be used for all tabular
    #: data associated with the **behaviorOptions**. Possible values are CONSTANT and LINEAR. The
    #: default value is CONSTANT.
    extrapolation: Literal[CONSTANT, LINEAR] = CONSTANT

    #: A :py:class:`~abaqus.Connector.ConnectorBehaviorOptionArray.ConnectorBehaviorOptionArray` object.
    behaviorOptions: Optional[ConnectorBehaviorOptionArray] = None

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        assembledType: Literal[
            NONE,
            BEAM,
            BUSHING,
            CVJOINT,
            CYLINDRICAL,
            HINGE,
            PLANAR,
            RETRACTOR,
            SLIPRING,
            TRANSLATOR,
            UJOINT,
            WELD,
        ] = NONE,
        rotationalType: Literal[
            NONE,
            ALIGN,
            CARDAN,
            CONSTANT_VELOCITY,
            EULER,
            FLEXION_TORSION,
            FLOW_CONVERTER,
            PROJECTION_FLEXION_TORSION,
            REVOLUTE,
            ROTATION,
            ROTATION_ACCELEROMETER,
            UNIVERSAL,
        ] = NONE,
        translationalType: Literal[
            NONE,
            ACCELEROMETER,
            AXIAL,
            CARTESIAN,
            JOIN,
            LINK,
            PROJECTION_CARTESIAN,
            RADIAL_THRUST,
            SLIDE_PLANE,
            SLOT,
        ] = NONE,
        integration: Literal[UNSPECIFIED, IMPLICIT, EXPLICIT] = UNSPECIFIED,
        u1ReferenceLength: Optional[float] = None,
        u2ReferenceLength: Optional[float] = None,
        u3ReferenceLength: Optional[float] = None,
        ur1ReferenceAngle: Optional[float] = None,
        ur2ReferenceAngle: Optional[float] = None,
        ur3ReferenceAngle: Optional[float] = None,
        massPerLength: Optional[float] = None,
        contactAngle: Optional[float] = None,
        materialFlowFactor: float = 1,
        regularize: Boolean = ON,
        defaultTolerance: Boolean = ON,
        regularization: float = 0,
        extrapolation: Literal[CONSTANT, LINEAR] = CONSTANT,
        behaviorOptions: ConnectorBehaviorOptionArray = ...,
    ) -> None:
        """This method creates a ConnectorSection object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].ConnectorSection
                session.odbs[name].ConnectorSection

        Parameters
        ----------
        name
            A String specifying the repository key.
        assembledType
            A SymbolicConstant specifying the assembled connection type. Possible values
            are:NONEBEAMBUSHINGCVJOINTCYLINDRICALHINGEPLANARRETRACTORSLIPRINGTRANSLATORUJOINTWELDThe
            default value is NONE.You cannot include the **assembledType** argument if
            **translationalType** or **rotationalType** are given a value other than NONE. At least one
            of the arguments **assembledType**, **translationalType**, or **rotationalType** must be given
            a value other than NONE.
        rotationalType
            A SymbolicConstant specifying the basic rotational connection type. Possible values
            are:NONEALIGNCARDANCONSTANT_VELOCITYEULERFLEXION_TORSIONFLOW_CONVERTERPROJECTION_FLEXION_TORSIONREVOLUTEROTATIONROTATION_ACCELEROMETERUNIVERSALThe
            default value is NONE.You cannot include the **rotationalType** argument if
            **assembledType** is given a value other than NONE. At least one of the arguments
            **assembledType**, **translationalType**, or **rotationalType** must be given an value other
            than NONE.
        translationalType
            A SymbolicConstant specifying the basic translational connection type. Possible values
            are:NONEACCELEROMETERAXIALCARTESIANJOINLINKPROJECTION_CARTESIANRADIAL_THRUSTSLIDE_PLANESLOTThe
            default value is NONE.You cannot include the **translationalType** argument if
            **assembledType** is given a value other than NONE. At least one of the arguments
            **assembledType**, **translationalType**, or **rotationalType** must be given an value other
            than NONE.
        integration
            A SymbolicConstant specifying the time integration scheme to use for analysis. This
            argument is applicable only to an Abaqus/Explicit analysis. Possible values are
            UNSPECIFIED, IMPLICIT, and EXPLICIT. The default value is UNSPECIFIED.
        u1ReferenceLength
            None or a Float specifying the reference length associated with constitutive response
            for the first component of relative motion. The default value is None.
        u2ReferenceLength
            None or a Float specifying the reference length associated with constitutive response
            for the second component of relative motion. The default value is None.
        u3ReferenceLength
            None or a Float specifying the reference length associated with constitutive response
            for the third component of relative motion. The default value is None.
        ur1ReferenceAngle
            None or a Float specifying the reference angle in degrees associated with constitutive
            response for the fourth component of relative motion. The default value is None.
        ur2ReferenceAngle
            None or a Float specifying the reference angle in degrees associated with constitutive
            response for the fifth component of relative motion. The default value is None.
        ur3ReferenceAngle
            None or a Float specifying the reference angle in degrees associated with constitutive
            response for the sixth component of relative motion. The default value is None.
        massPerLength
            None or a Float specifying the mass per unit reference length of belt material. This
            argument is applicable only when **assembledType** = SLIPRING, and must be specified in that
            case. The default value is None.
        contactAngle
            None or a Float specifying the contact angle made by the belt wrapping around node b.
            This argument is applicable only to an Abaqus/Explicit analysis, and only when
            **assembledType** = SLIPRING. The default value is None.
        materialFlowFactor
            A Float specifying the scaling factor for material flow at node b. This argument is
            applicable only when **assembledType** = RETRACTOR or **rotationalType** = FLOW_CONVERTER. The
            default value is 1.0.
        regularize
            A Boolean specifying whether or not all tabular data associated with the
            **behaviorOptions** will be regularized. This argument is applicable only for an
            Abaqus/Explicit analysis. The default value is ON.
        defaultTolerance
            A Boolean specifying whether or not the default regularization tolerance will be used
            for all tabular data associated with the **behaviorOptions**. This argument is applicable
            only for an Abaqus/Explicit analysis and only if **regularize** = ON. The default value is
            ON.
        regularization
            A Float specifying the regularization increment to be used for all tabular data
            associated with the **behaviorOptions**. This argument is applicable only for an
            Abaqus/Explicit analysis and only if **regularize** = ON and **defaultTolerance** = OFF. The
            default value is 0.03.
        extrapolation
            A SymbolicConstant specifying the extrapolation technique to be used for all tabular
            data associated with the **behaviorOptions**. Possible values are CONSTANT and LINEAR. The
            default value is CONSTANT.
        behaviorOptions
            A :py:class:`~abaqus.Connector.ConnectorBehaviorOptionArray.ConnectorBehaviorOptionArray` object.

        Returns
        -------
        ConnectorSection
            A :py:class:`~abaqus.Connector.ConnectorSection.ConnectorSection` object.

        Raises
        ------
        InvalidNameError
        RangeError
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        assembledType: Literal[
            NONE,
            BEAM,
            BUSHING,
            CVJOINT,
            CYLINDRICAL,
            HINGE,
            PLANAR,
            RETRACTOR,
            SLIPRING,
            TRANSLATOR,
            UJOINT,
            WELD,
        ] = NONE,
        rotationalType: Literal[
            NONE,
            ALIGN,
            CARDAN,
            CONSTANT_VELOCITY,
            EULER,
            FLEXION_TORSION,
            FLOW_CONVERTER,
            PROJECTION_FLEXION_TORSION,
            REVOLUTE,
            ROTATION,
            ROTATION_ACCELEROMETER,
            UNIVERSAL,
        ] = NONE,
        translationalType: Literal[
            NONE,
            ACCELEROMETER,
            AXIAL,
            CARTESIAN,
            JOIN,
            LINK,
            PROJECTION_CARTESIAN,
            RADIAL_THRUST,
            SLIDE_PLANE,
            SLOT,
        ] = NONE,
        integration: Literal[UNSPECIFIED, IMPLICIT, EXPLICIT] = UNSPECIFIED,
        u1ReferenceLength: Optional[float] = None,
        u2ReferenceLength: Optional[float] = None,
        u3ReferenceLength: Optional[float] = None,
        ur1ReferenceAngle: Optional[float] = None,
        ur2ReferenceAngle: Optional[float] = None,
        ur3ReferenceAngle: Optional[float] = None,
        massPerLength: Optional[float] = None,
        contactAngle: Optional[float] = None,
        materialFlowFactor: float = 1,
        regularize: Boolean = ON,
        defaultTolerance: Boolean = ON,
        regularization: float = 0,
        extrapolation: Literal[CONSTANT, LINEAR] = CONSTANT,
        behaviorOptions: ConnectorBehaviorOptionArray = ...,
    ) -> None:
        """This method modifies the ConnectorSection object.

        Parameters
        ----------
        assembledType
            A SymbolicConstant specifying the assembled connection type. Possible values
            are:NONEBEAMBUSHINGCVJOINTCYLINDRICALHINGEPLANARRETRACTORSLIPRINGTRANSLATORUJOINTWELDThe
            default value is NONE.You cannot include the **assembledType** argument if
            **translationalType** or **rotationalType** are given a value other than NONE. At least one
            of the arguments **assembledType**, **translationalType**, or **rotationalType** must be given
            a value other than NONE.
        rotationalType
            A SymbolicConstant specifying the basic rotational connection type. Possible values
            are:NONEALIGNCARDANCONSTANT_VELOCITYEULERFLEXION_TORSIONFLOW_CONVERTERPROJECTION_FLEXION_TORSIONREVOLUTEROTATIONROTATION_ACCELEROMETERUNIVERSALThe
            default value is NONE.You cannot include the **rotationalType** argument if
            **assembledType** is given a value other than NONE. At least one of the arguments
            **assembledType**, **translationalType**, or **rotationalType** must be given an value other
            than NONE.
        translationalType
            A SymbolicConstant specifying the basic translational connection type. Possible values
            are:NONEACCELEROMETERAXIALCARTESIANJOINLINKPROJECTION_CARTESIANRADIAL_THRUSTSLIDE_PLANESLOTThe
            default value is NONE.You cannot include the **translationalType** argument if
            **assembledType** is given a value other than NONE. At least one of the arguments
            **assembledType**, **translationalType**, or **rotationalType** must be given an value other
            than NONE.
        integration
            A SymbolicConstant specifying the time integration scheme to use for analysis. This
            argument is applicable only to an Abaqus/Explicit analysis. Possible values are
            UNSPECIFIED, IMPLICIT, and EXPLICIT. The default value is UNSPECIFIED.
        u1ReferenceLength
            None or a Float specifying the reference length associated with constitutive response
            for the first component of relative motion. The default value is None.
        u2ReferenceLength
            None or a Float specifying the reference length associated with constitutive response
            for the second component of relative motion. The default value is None.
        u3ReferenceLength
            None or a Float specifying the reference length associated with constitutive response
            for the third component of relative motion. The default value is None.
        ur1ReferenceAngle
            None or a Float specifying the reference angle in degrees associated with constitutive
            response for the fourth component of relative motion. The default value is None.
        ur2ReferenceAngle
            None or a Float specifying the reference angle in degrees associated with constitutive
            response for the fifth component of relative motion. The default value is None.
        ur3ReferenceAngle
            None or a Float specifying the reference angle in degrees associated with constitutive
            response for the sixth component of relative motion. The default value is None.
        massPerLength
            None or a Float specifying the mass per unit reference length of belt material. This
            argument is applicable only when **assembledType** = SLIPRING, and must be specified in that
            case. The default value is None.
        contactAngle
            None or a Float specifying the contact angle made by the belt wrapping around node b.
            This argument is applicable only to an Abaqus/Explicit analysis, and only when
            **assembledType** = SLIPRING. The default value is None.
        materialFlowFactor
            A Float specifying the scaling factor for material flow at node b. This argument is
            applicable only when **assembledType** = RETRACTOR or **rotationalType** = FLOW_CONVERTER. The
            default value is 1.0.
        regularize
            A Boolean specifying whether or not all tabular data associated with the
            **behaviorOptions** will be regularized. This argument is applicable only for an
            Abaqus/Explicit analysis. The default value is ON.
        defaultTolerance
            A Boolean specifying whether or not the default regularization tolerance will be used
            for all tabular data associated with the **behaviorOptions**. This argument is applicable
            only for an Abaqus/Explicit analysis and only if **regularize** = ON. The default value is
            ON.
        regularization
            A Float specifying the regularization increment to be used for all tabular data
            associated with the **behaviorOptions**. This argument is applicable only for an
            Abaqus/Explicit analysis and only if **regularize** = ON and **defaultTolerance** = OFF. The
            default value is 0.03.
        extrapolation
            A SymbolicConstant specifying the extrapolation technique to be used for all tabular
            data associated with the **behaviorOptions**. Possible values are CONSTANT and LINEAR. The
            default value is CONSTANT.
        behaviorOptions
            A :py:class:`~abaqus.Connector.ConnectorBehaviorOptionArray.ConnectorBehaviorOptionArray` object.

        Raises
        ------
        RangeError
        """
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class MesherOptions:
    """The MesherOptions object controls the default settings that Abaqus uses for all meshing
    methods. The MesherOptions object has no constructor. Abaqus creates the **MesherOptions**
    member when a session is started.
    MesherOptions commands are intended for use at the beginning of scripts and in the
    abaqus_v6.env file only; they should not be used during an Abaqus/CAE session.

    .. note:: 
        This object can be accessed by::

            session.defaultMesherOptions
    """

    @abaqus_method_doc
    def setValues(
        self,
        elemShape2D: SymbolicConstant = QUAD_DOMINATED,
        elemShape3D: SymbolicConstant = HEX,
        quadAlgorithm: SymbolicConstant = ADVANCING_FRONT,
        allowMapped: Boolean = OFF,
        minTransition: Boolean = ON,
    ):
        """This method modifies the MesherOptions object.

        Parameters
        ----------
        elemShape2D
            A SymbolicConstant specifying the default element shape for meshing two-dimensional
            objects. Possible values are QUAD, QUAD_DOMINATED, and TRI. The default value is
            QUAD_DOMINATED.
        elemShape3D
            A SymbolicConstant specifying the default element shape for meshing three-dimensional
            objects. Possible values are HEX, HEX_DOMINATED, WEDGE, and TET. The default value is
            HEX.
        quadAlgorithm
            A SymbolicConstant specifying the default algorithm for meshing an object with quad- or
            quad-dominated elements. Possible values are ADVANCING_FRONT and MEDIAL_AXIS. The
            default value is ADVANCING_FRONT.
        allowMapped
            A Boolean specifying whether Abaqus/CAE should allow mapped meshing, where appropriate.
            The default value is OFF.
        minTransition
            A Boolean specifying whether Abaqus/CAE should attempt to minimize the mesh transition
            when it moves from a coarse mesh to a fine mesh. The default value is ON.
        """
        ...



from abqpy.decorators import abaqus_class_doc


@abaqus_class_doc
class SectorDefinition:
    """The SectorDefinition object describes the number of symmetry sectors and axis of
    symmetry for a cyclic symmetry model.

    .. note:: 
        This object can be accessed by::

            import odbAccess
            session.odbs[name].sectorDefinition
    """

    #: An Int specifying the number of sectors in the cyclic symmetry model.
    numSectors: int = None

    #: A tuple of tuples of Floats specifying the coordinates of two points on the axis of
    #: symmetry.
    symmetryAxis: float = None
